Module task_notification

Module task_notification 

JMAP Tasks — TaskNotification/* method implementations on SessionClient.

TaskNotification/set is destroy-only. Any create or update entries from the client would be rejected by the server with forbidden, but we expose a typed API that only allows destroy to avoid client-side confusion.